@@ -8,7 +8,7 @@ test_that("error when you send other objects to diagnose", {
 
 
 test_that("default diagnosands work", {
-  my_designer <- function(N = 500) {
+  my_designer <- function(N = 10) {
     my_population <- declare_population(N = N, noise = rnorm(N))
 
     my_potential_outcomes <-
@@ -20,14 +20,14 @@ test_that("default diagnosands work", {
 
     my_estimator <- declare_estimator(Y ~ Z, inquiry = my_inquiry)
 
-    my_reveal <- declare_reveal()
+    my_measurement <- declare_measurement(Y = reveal_outcomes(Y ~ Z)) 
 
     design <- my_population +
       my_potential_outcomes +
       my_inquiry +
       declare_step(dplyr::mutate, q = 5) +
       my_assignment +
-      my_reveal +
+      my_measurement +
       my_estimator
 
     diagnosands <- declare_diagnosands(med_bias = median(estimate - estimand))
@@ -57,7 +57,12 @@ test_that("default diagnosands work", {
     design_1 = design_1,
     sims = 2
   )
-
+  
+  # test tidy.diagnosis
+  expect_equal(dim(tidy(diag)), c(2, 9))
+  expect_equal(names(tidy(diag)), c("design", "inquiry", "estimator", "term", "diagnosand", "estimate", 
+                                    "std.error", "conf.low", "conf.high"))
+  
   expect_equal(names(diag$diagnosands_df), 
                c("design", "inquiry", "estimator", "term", 
                  "med_bias", "se(med_bias)", "n_sims"
@@ -78,6 +83,11 @@ test_that("default diagnosands work", {
     sims = 2
   )
   
+  # test tidy.diagnosis
+  expect_equal(dim(tidy(diag)), c(4, 9))
+  expect_equal(names(tidy(diag)), c("design", "inquiry", "estimator", "term", "diagnosand", "estimate", 
+                                    "std.error", "conf.low", "conf.high"))
+  
   expect_equal(names(diag$diagnosands_df), c("design", "inquiry", "estimator", "term", 
                                              "my_bias", "se(my_bias)", "my_power", 
                                              "se(my_power)", "n_sims"))
@@ -91,11 +101,15 @@ test_that("default diagnosands work", {
   )
   
   expect_equal(names(diag$diagnosands_df), 
-               c("design", "inquiry", "estimator", "term", 
-                 "bias", "se(bias)", "rmse", "se(rmse)", "power", "se(power)", 
-                 "coverage", "se(coverage)", "mean_estimate", "se(mean_estimate)", 
-                 "sd_estimate", "se(sd_estimate)", "mean_se", "se(mean_se)", "type_s_rate", 
-                 "se(type_s_rate)", "mean_estimand", "se(mean_estimand)", "n_sims"))
+               c("design", "inquiry", "estimator", "term", "mean_estimand", 
+                 "se(mean_estimand)", "mean_estimate", "se(mean_estimate)", "bias", 
+                 "se(bias)", "sd_estimate", "se(sd_estimate)", "rmse", "se(rmse)", 
+                 "power", "se(power)", "coverage", "se(coverage)", "n_sims"))
+  
+  # test tidy.diagnosis
+  expect_equal(dim(tidy(diag)), c(14, 9))
+  expect_equal(names(tidy(diag)), c("design", "inquiry", "estimator", "term", "diagnosand", "estimate", 
+                                    "std.error", "conf.low", "conf.high"))
   
   # w/ none set and override
 
@@ -111,6 +125,10 @@ test_that("default diagnosands work", {
                  "med_bias", "se(med_bias)", "n_sims"
                ))
   
+  # test tidy.diagnosis
+  expect_equal(dim(tidy(diag)), c(2, 9))
+  expect_equal(names(tidy(diag)), c("design", "inquiry", "estimator", "term", "diagnosand", "estimate", 
+                                    "std.error", "conf.low", "conf.high"))
   
   # w/ mix of set and unset
   
@@ -126,23 +144,35 @@ test_that("default diagnosands work", {
                c("design", "N", "inquiry", "estimator", "term", 
                  "med_bias", "n_sims"))
   
+  # test tidy.diagnosis
+  expect_equal(dim(tidy(diag)), c(2, 7))
+  expect_equal(names(tidy(diag)), c("design", "inquiry", "estimator", "term", "N", "diagnosand", "estimate"))
+  
   # w mix of diagnosands set
 
   attr(designs[[1]], "diagnosands") <- NULL
 
   diag <- diagnose_design(designs, sims = 5, bootstrap_sims = FALSE)
   
-  expect_equal(ncol(diag$diagnosands_df), 16)
+  expect_equal(ncol(diag$diagnosands_df), 14)
+  
+  # test tidy.diagnosis
+  expect_equal(dim(tidy(diag)), c(16, 7))
+  expect_equal(names(tidy(diag)), c("design", "inquiry", "estimator", "term", "N", "diagnosand", "estimate"))
   
   # // simulation df
   sims <- set_diagnosands(simulate_design(designs, sims = 5), declare_diagnosands(med_bias = median(estimate - estimand)))
   diag <- diagnose_design(sims, sims = 5, bootstrap_sims = FALSE)
+  
+  # test tidy.diagnosis
+  expect_equal(dim(tidy(diag)), c(2, 7))
+  expect_equal(names(tidy(diag)), c("design", "inquiry", "estimator", "term", "N", "diagnosand", "estimate"))
 })
 
 
 test_that("more term",{
   population  <-
-    declare_population(N = 100,
+    declare_model(N = 100,
                        Z = rep(0:1, 50),
                        Y = rnorm(N))
   
@@ -193,7 +223,7 @@ test_that("diagnose_design does not reclass the variable N", {
   skip_if(compareVersion("3.5", paste(R.Version()$major, R.Version()$minor, sep = ".")) == 1)
   # works for redesign
   design <-
-    declare_population(N = 5, noise = rnorm(N)) +
+    declare_model(N = 5, noise = rnorm(N)) +
        declare_inquiry(mean_noise = mean(noise))
   
   designs <- redesign(design, N = 5:10) 
@@ -202,9 +232,12 @@ test_that("diagnose_design does not reclass the variable N", {
   expect_equal(class(dx$simulations_df$N), "integer") 
   expect_equal(class(dx$diagnosands_df$N), "integer")
   
+  # test tidy.diagnosis
+  expect_equal(class(tidy(dx)$N), "integer") 
+  
   # works for expand_design
   designer <- function(N = 5) {
-    declare_population(N = N, noise = rnorm(N)) +
+    declare_model(N = N, noise = rnorm(N)) +
     declare_inquiry(mean_noise = mean(noise))
   }
   
@@ -214,12 +247,15 @@ test_that("diagnose_design does not reclass the variable N", {
   expect_equal(class(dx$simulations_df$N), "integer") 
   expect_equal(class(dx$diagnosands_df$N), "integer")
   
+  # test tidy.diagnosis
+  expect_equal(class(tidy(dx)$N), "integer") 
+  
 })
 
 
 test_that("diagnose_design works when simulations_df lacking parameters attr", {
 
-  design <- declare_population(N = 100, X = rnorm(N), Y = rnorm(N, X)) +
+  design <- declare_model(N = 100, X = rnorm(N), Y = rnorm(N, X)) +
     declare_inquiry(true_effect = 1) +
     declare_estimator(Y ~ X, model=lm_robust, inquiry = "true_effect", label = "Y on X") 
   
@@ -237,8 +273,14 @@ test_that("diagnose_design works when simulations_df lacking parameters attr", {
   d1$simulations_df$design <- as.character(d1$simulations_df$design)
   d1$diagnosands_df$design <- as.character(d1$diagnosands_df$design)
   d1["parameters_df"] <- list(NULL)
+  d1$duration <- NULL
+  d2$duration <- NULL # dropped because durations will always be slightly different
     
   expect_identical(d1,d2)
+  
+  # test tidy.diagnosis
+  expect_identical(tidy(d1), tidy(d2))
+  
 })
 
 
@@ -251,11 +293,13 @@ test_that("diagnose_design can generate and use grouping variables", {
   set.seed(5)
   
   design <- 
-    declare_population(N = 100, u = rnorm(N)) + 
-    declare_potential_outcomes(Y_Z_0 = 0, Y_Z_1 = ifelse(rbinom(N, 1, prob = 0.5), 0.1, -0.1) + u) +
+    declare_model(N = 100, u = rnorm(N),
+      Y_Z_0 = 0, 
+      Y_Z_1 = ifelse(rbinom(N, 1, prob = 0.5), 0.1, -0.1) + u
+    ) +
     declare_assignment(Z = complete_ra(N)) + 
     declare_inquiry(ATE_positive = mean(Y_Z_1 - Y_Z_0) > 0) + 
-    declare_reveal() + 
+    declare_measurement(Y = reveal_outcomes(Y ~ Z)) +
     declare_estimator(Y ~ Z, inquiry = "ATE_positive")
   
   diagnosis <- diagnose_design(design, 
@@ -265,12 +309,19 @@ test_that("diagnose_design can generate and use grouping variables", {
   expect_equivalent(diagnosis$diagnosands_df$significant,  c(FALSE, FALSE))
   expect_equivalent(diagnosis$diagnosands_df$estimand,  c(FALSE, TRUE))
   
+  # test tidy.diagnosis
+  expect_equal(dim(tidy(diagnosis)), c(14, 11))
+  expect_equal(names(tidy(diagnosis)), c("design", "inquiry", "estimator", "term", "estimand", "significant", "diagnosand", "estimate", 
+                                         "std.error", "conf.low", "conf.high"))
+  
   design <- 
-    declare_population(N = 100, u = rnorm(N)) + 
-    declare_potential_outcomes(Y_Z_0 = 0, Y_Z_1 = ifelse(rbinom(N, 1, prob = 0.5), 0.1, -0.1) + u) +
+    declare_model(N = 100, u = rnorm(N),
+      Y_Z_0 = 0, 
+      Y_Z_1 = ifelse(rbinom(N, 1, prob = 0.5), 0.1, -0.1) + u
+    ) +
     declare_assignment(Z = complete_ra(N)) + 
     declare_inquiry(ATE = mean(Y_Z_1 - Y_Z_0)) + 
-    declare_reveal() + 
+    declare_measurement(Y = reveal_outcomes(Y ~ Z)) +
     declare_estimator(Y ~ Z, inquiry = "ATE")
   
   diagnosis <- diagnose_design(
@@ -283,14 +334,20 @@ test_that("diagnose_design can generate and use grouping variables", {
   
   expect_equivalent(nrow(diagnosis$diagnosands_df),  4)
   
+  # test tidy.diagnosis
+  expect_equal(dim(tidy(diagnosis)), c(28, 10))
+  expect_equal(names(tidy(diagnosis)), c("design", "inquiry", "estimator", "term", "effect_size", "diagnosand", 
+                                         "estimate", "std.error", "conf.low", "conf.high"))
   
   
   design <- 
-    declare_population(N = 100, u = rnorm(N)) + 
-    declare_potential_outcomes(Y_Z_0 = 0, Y_Z_1 = ifelse(rbinom(N, 1, prob = 0.5), 0.1, -0.1) + u) +
+    declare_model(N = 100, u = rnorm(N),
+      Y_Z_0 = 0, 
+      Y_Z_1 = ifelse(rbinom(N, 1, prob = 0.5), 0.1, -0.1) + u
+    ) +
     declare_assignment(Z = complete_ra(N)) + 
     declare_inquiry(ATE_positive = mean(Y_Z_1 - Y_Z_0) > 0) + 
-    declare_reveal() + 
+    declare_measurement(Y = reveal_outcomes(Y ~ Z)) +
     declare_estimator(Y ~ Z, inquiry = "ATE_positive")
   
   diagnosis <- diagnose_design(design, 
@@ -298,6 +355,11 @@ test_that("diagnose_design can generate and use grouping variables", {
                                sims = 5
   )
   
+  # test tidy.diagnosis
+  expect_equal(dim(tidy(diagnosis)), c(14, 10))
+  expect_equal(names(tidy(diagnosis)), c("design", "inquiry", "estimator", "term", "significant", "diagnosand", 
+                                         "estimate", "std.error", "conf.low", "conf.high"))
+  
   print(diagnosis, digits = 5, select = "Bias")
   
   diagnosis <- diagnose_design(design, 
@@ -305,4 +367,55 @@ test_that("diagnose_design can generate and use grouping variables", {
                                sims = 100
   )
   
+  # test tidy.diagnosis
+  expect_equal(dim(tidy(diagnosis)), c(21, 10))
+  expect_equal(names(tidy(diagnosis)), c("design", "inquiry", "estimator", "term", "significant", "diagnosand", 
+                                         "estimate", "std.error", "conf.low", "conf.high"))
+  
+  
 })
+
+
+test_that("tidy.diagnosis handles NAs", {
+  
+  design <- 
+    declare_model(N = 10, Y = rnorm(N)) +
+    declare_estimator(Y ~ 1, label = "normal") +
+    declare_estimator(handler = function(data){data.frame(estimate = 5)})
+  
+  dx <- diagnose_design(design, sims = 5)
+  
+  expect_equal(dim(tidy(dx)), c(14, 8))
+  
+  set.seed(343)
+  portola <-
+    fabricate(
+      N = 2100,
+      Y_star = rnorm(N)
+    )
+  
+  design <- 
+    declare_model(data = portola) + 
+    declare_measurement(Y = as.numeric(cut(Y_star, 7))) + 
+    declare_inquiry(Y_bar = mean(Y)) + 
+    declare_sampling(S = complete_rs(N, n = 100)) + 
+    declare_measurement(
+      R = rbinom(n = N, size = 1, prob = pnorm(Y_star + effort)),
+      Y = ifelse(R == 1, Y, NA_real_)
+    ) +
+    declare_estimator(Y ~ 1, inquiry = "Y_bar") +
+    declare_estimator(R ~ 1, label = "Response Rate")
+  
+  designs <- redesign(design, effort = seq(0, 5, by = 1))
+  diagnosis <-
+    diagnose_designs(
+      designs,
+      sims = 20,
+      bootstrap_sims = 20
+    )
+  
+  # checks a bug involved in sorting that led to NAs in mean estimate (possibly related to the case where you have parameters?)
+  expect_equal(sum(is.na(tidy(diagnosis) %>% dplyr::filter(diagnosand == "mean_estimate", estimator == "estimator") %>% dplyr::pull(estimate))), 0)
+  
+})
+
